// ------------------------------------------------------------------------------
// Springs - http://www.arkitus.com
// Copyright (C) 2005  Ali Eslami
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// ------------------------------------------------------------------------------
// HScroller.java
// A GUI element used to adjust various settings such as gravity or bounce k.
// ------------------------------------------------------------------------------

class HScroller
{
  float min;
  float max;
  float def;
  float x;
  float y;
  float xpos;
  float w;
  float scale;
  float value;
  boolean locked;
  
  HScroller( float Min, float Max, float Default, float X, float Y, float W )
  {
    min = Min;
    max = Max;
    x = X;
    y = Y;
    w = W;
    
    scale = ( max - min ) / w;
    def = ( Default - min ) / scale;
    xpos = def;
  }
  
  float update()
  {
    drag();
    display();
    readValue();
    
    return value;
  }
  
  void drag()
  {
    if ( mousePressed && over() )
    {
      locked = true;
    }
    if ( !mousePressed )
    {
      locked = false;
    }
    if ( locked )
    {
      assignPos(mouseX-x);
    }
  }
  
  void assignPos( float X )
  {
    xpos = X;
    
    if ( X > w )
    {
      xpos = w;
    }
    if ( X < 0 )
    {
      xpos = 0;
    }
  }
  
  void readValue()
  {
    value = xpos*scale + min;
  }
  
  void display()
  {
    noSmooth();
    stroke(200,200,200);
    fill(230,230,230);
    strokeWeight(1);
    line(x,y,x+w,y);
    line(x+def, y-2, x+def, y+2);
    rectMode(CENTER);
    stroke(100,100,100);
    rect(x+xpos, y, 5, 5);
    smooth();
  }
  
  boolean over() 
  { 
    if( mouseX > x - 10 && mouseX < x + w + 10 && mouseY > y - 10 && mouseY < y + 10 ) 
    { 
      return true; 
    } 
    else
    { 
      return false; 
    } 
  }
}
