// ------------------------------------------------------------------------------
// Springs - http://www.arkitus.com
// Copyright (C) 2005  Ali Eslami
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// ------------------------------------------------------------------------------
// Object.java
// Something that gets connected to another object by a spring.
// ------------------------------------------------------------------------------

class Object
{
  float x;
  float y;
  float m;
  float r;
  float f;
  float wx;
  float wy;
  float tx;
  float ty;
  float vx;
  float vy;
  boolean locked;
  
  Object( float X, float Y, float M, float F )
  {
    x = abs(X);
    y = abs(Y);
    m = M;
    r = M;
    f = F;
    
    tx = ty = vx = vy = 0;
    locked = false;
  }
  
  void display()
  {
    stroke(0,0,0);
    strokeWeight(3);
    fill(100+f*155, 100+f*155, 100+f*155);
    ellipse(x,y,2*r,2*r);
  }
  
  void bounce()
  {
    // Bounce off the walls
    if ( y + vy + r > height-3 && vy > 0 )
    {
      y = height - r - 3;
      vx *= fk;
      vy *= -fb;
    }
    if ( y + vy - r < 3 )
    {
      y = r + 3;
      vx *= fk;
      vy *= -fb;
    }
    if ( x + vx + r > width-3 )
    {
      x = width - r - 3;
      vx *= -fb;
      vy *= fk;
    }
    if ( x + vx - r < 3 )
    {
      x = r + 3;
      vx *= -fb;
      vy *= fk;
    }
  }
  
  void fall()
  {
    wx = 0;
    wy = m*fg;
  }

  void move()
  {
    float fx = tx + wx;
    float fy = ty + wy;
    
    tx = ty = 0;
    
    float ax = fx/m;
    float ay = fy/m;
    
    vx += f*ax;
    vy += f*ay;
    
    vx *= fd;
    vy *= fd;
       
    if ( ( x + vx < width - r || vx <= 0 ) && ( x + vx > r || vx >= 0 ) )
    {
      x += vx;
    }
    else
    {
      vx = 0;
    }
    if ( ( y + vy < height - r || vy <= 0 ) && ( y + vy > r || vy >= 0 ) )
    {
      y += vy;
    }
    else
    {
      vy = 0;
    }
  }
  
  void checkClick()
  {
    if ( over() )
    {
      locked = true;
    }
  }
   
  void drag()
  {
    if ( !mousePressed )
    {
      locked = false;
    }
    if ( locked )
    {
      assignPos(mouseX, mouseY);
    }
  }
  
  void assignPos( float X, float Y )
  {
    x = X;
    y = Y;
    
    tx = ty = wx = wy = vx = vy = 0;
  }
  
  boolean over() 
  { 
    if( mouseX > x - 2*r && mouseX < x + 2*r && mouseY > y - 2*r && mouseY < y + 2*r ) 
    { 
      return true; 
    } 
    else
    { 
      return false; 
    } 
  }
}
