// ------------------------------------------------------------------------------
// Springs - http://www.arkitus.com
// Copyright (C) 2005  Ali Eslami
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// ------------------------------------------------------------------------------
// Springs.java
// Procedures related to starting up the program and adjusting the settings
// are in this file.
// ------------------------------------------------------------------------------

int num_s;
int num_o;
int num_p;

float fb = 0.9;             // Bounce constant.
float fk = 0.1;             // Friction constant.
float fr;                   // Spring constant.
float fg;                   // Gravity constant.
float fd;                   // Damping constant.
float fl;                   // Length constant.

Spring[] Springs;           // Create spring array.
Object[] Objects;           // Create object array.  
HScroller LengthS;          // Create scrollers.
HScroller GravityS;         // Create scrollers.
HScroller SpringS;          // Create scrollers.
HScroller DampingS;         // Create scrollers.

PFont font; 


void setup()
{
  // Applet Settings
  
  size(800,420);
  framerate(30);
  smooth();
  font = loadFont("Verdana-10.vlw"); 
  textFont(font, 10); 

  // Create Scrollers
  
  LengthS = new HScroller(0.2, 1.5, 1, 700, 310, 50);
  GravityS = new HScroller(-1, 10, 4, 700, 330, 50);
  SpringS = new HScroller(0.2, 5, 3.5, 700, 350, 50);
  DampingS = new HScroller(0.1, 0.95, 0.8, 700, 370, 50);
    
  // Create Objects
  
  num_o = 18;          
  Objects = new Object[num_o];
  
  Objects[0] = new Object(200, 210, 5, 1);
  Objects[1] = new Object(200, 210, 5, 1);
  Objects[2] = new Object(200, 210, 5, 1);
  Objects[3] = new Object(200, 210, 5, 1);
  
  Objects[4] = new Object(400, 210, 5, 1);
  Objects[5] = new Object(400, 210, 5, 1);
  Objects[6] = new Object(400, 210, 5, 1);
  
  Objects[7] = new Object(600, 210, 5, 1);
  Objects[8] = new Object(600, 210, 5, 1);
  Objects[9] = new Object(600, 210, 5, 1);
  Objects[10] = new Object(600, 210, 5, 1);
  Objects[11] = new Object(600, 210, 5, 1);  
  
  Objects[12] = new Object(300, 250, 5, 0);  
  Objects[13] = new Object(500, 250, 5, 0);  
  
  Objects[14] = new Object(400, 50, 5, 1);  
  Objects[15] = new Object(400, 50, 5, 1);  
  Objects[16] = new Object(400, 50, 5, 1);  
  Objects[17] = new Object(400, 50, 5, 0);  
  
  // Create springs
  
  num_s = 24;
  Springs = new Spring[num_s];

  Springs[0] = new Spring(0,1,100);
  Springs[1] = new Spring(1,2,100);
  Springs[2] = new Spring(2,3,100);
  Springs[3] = new Spring(3,0,100);
  Springs[4] = new Spring(1,3,100);
  Springs[5] = new Spring(2,0,100);
  
  Springs[6] = new Spring(4,5,50);
  Springs[7] = new Spring(5,6,50);
  Springs[8] = new Spring(6,4,50);
  
  Springs[9] = new Spring(7,8,100);
  Springs[10] = new Spring(8,9,100);
  Springs[11] = new Spring(9,10,100);
  Springs[12] = new Spring(10,11,100);
  Springs[13] = new Spring(11,7,100);
  Springs[14] = new Spring(11,8,50);
  Springs[15] = new Spring(11,9,50);
  Springs[16] = new Spring(10,8,50);
  Springs[17] = new Spring(10,7,50);
  Springs[18] = new Spring(9,7,50);
  
  Springs[19] = new Spring(5,13,100);
  Springs[20] = new Spring(6,12,100);
  
  Springs[21] = new Spring(14,15,50);
  Springs[22] = new Spring(15,16,50);
  Springs[23] = new Spring(16,17,50);
}

void draw()
{
  background(255,255,255);
  
  for ( int i=0; i<num_s; i++ )
  {
    Springs[i].pull();
  }
   
  for ( int i=0; i<num_o; i++ )
  {
    Objects[i].bounce();
    Objects[i].drag();
    Objects[i].fall();
    Objects[i].move();
  }
  
  for ( int i=0; i<num_s; i++ )
  {
    Springs[i].display();
  }
  
  for ( int i=0; i<num_o; i++ )
  {
    Objects[i].display();
  }
  
  fl = LengthS.update();
  fg = GravityS.update();
  fr = SpringS.update();
  fd = DampingS.update();
  
  fill(100,100,100);
  text("l", 760,312);
  text("g", 760,332);
  text("k", 760,352);
  text("b", 760,372);
}

void mousePressed()
{
  for ( int i=0; i<num_o; i++ )
  {
    Objects[i].checkClick();
  }
}
